pm4py.algo.conformance.antialignments.variants package
======================================================

Submodules
----------

pm4py.algo.conformance.antialignments.variants.discounted\_a\_star module
-------------------------------------------------------------------------

.. automodule:: pm4py.algo.conformance.antialignments.variants.discounted_a_star
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.algo.conformance.antialignments.variants
   :members:
   :undoc-members:
   :show-inheritance:
